Expression

Enum Expression 

pub enum Expression {
Show 16 variants Null(Decorated<Null>), Bool(Decorated<bool>), Number(Formatted<Number>), String(Decorated<String>), Array(Array), Object(Object), StringTemplate(StringTemplate), HeredocTemplate(Box<HeredocTemplate>), Parenthesis(Box<Parenthesis>), Variable(Decorated<Ident>), Conditional(Box<Conditional>), FuncCall(Box<FuncCall>), Traversal(Box<Traversal>), UnaryOp(Box<UnaryOp>), BinaryOp(Box<BinaryOp>), ForExpr(Box<ForExpr>),
}
A type representing any expression from the expression sub-language.

Variants



Null(Decorated<Null>)

Represents a null value.



Bool(Decorated<bool>)

Represents a boolean.



Number(Formatted<Number>)

Represents a number, either integer or float.



String(Decorated<String>)

Represents a string that does not contain any template interpolations or template directives.



Array(Array)

Represents an HCL array.



Object(Object)

Represents an HCL object.



StringTemplate(StringTemplate)

Represents a string containing template interpolations and template directives.



HeredocTemplate(Box<HeredocTemplate>)

Represents an HCL heredoc template.



Parenthesis(Box<Parenthesis>)

Represents a sub-expression wrapped in parenthesis.



Variable(Decorated<Ident>)

Represents a variable identifier.



Conditional(Box<Conditional>)

Represents conditional operator which selects one of two rexpressions based on the outcome of a boolean expression.



FuncCall(Box<FuncCall>)

Represents a function call.



Traversal(Box<Traversal>)

Represents an attribute or element traversal.



UnaryOp(Box<UnaryOp>)

Represents an operation which applies a unary operator to an expression.



BinaryOp(Box<BinaryOp>)

Represents an operation which applies a binary operator to two expressions.



ForExpr(Box<ForExpr>)

Represents a construct for constructing a collection by projecting the items from another collection.

Implementations

Source

impl Expression

pub fn null() -> Expression

Creates a null expression.

pub fn is_null(&self) -> bool

Returns true if the expression represents null.

pub fn is_bool(&self) -> bool

Returns true if the expression is a bool.

pub fn as_bool(&self) -> Option<bool>

If the expression is a bool, returns a reference to it, otherwise None.

pub fn is_number(&self) -> bool

Returns true if the expression is a number.

pub fn as_number(&self) -> Option<&Number>

If the expression is a number, returns a reference to it, otherwise None.

pub fn is_str(&self) -> bool

Returns true if the expression is a string.

pub fn as_str(&self) -> Option<&str>

If the expression is a string, returns a reference to it, otherwise None.

pub fn is_array(&self) -> bool

Returns true if the expression is an array.

pub fn as_array(&self) -> Option<&Array>

If the expression is an array, returns a reference to it, otherwise None.

pub fn as_array_mut(&mut self) -> Option<&mut Array>

If the expression is an array, returns a mutable reference to it, otherwise None.

pub fn is_object(&self) -> bool

Returns true if the expression is an object.

pub fn as_object(&self) -> Option<&Object>

If the expression is an object, returns a reference to it, otherwise None.

pub fn as_object_mut(&mut self) -> Option<&mut Object>

If the expression is an object, returns a mutable reference to it, otherwise None.

pub fn is_template(&self) -> bool

Returns true if the expression is either of variant StringTemplate or HeredocTemplate.

pub fn as_template(&self) -> Option<&Template>

If the expression is either of variant StringTemplate or HeredocTemplate, returns a reference to the underlying Template, otherwise None.

pub fn is_string_template(&self) -> bool

Returns true if the expression is a string template.

pub fn as_string_template(&self) -> Option<&StringTemplate>

If the expression is a string template, returns a reference to it, otherwise None.

pub fn is_heredoc_template(&self) -> bool

Returns true if the expression is a heredoc template.

pub fn as_heredoc_template(&self) -> Option<&HeredocTemplate>

If the expression is a heredoc template, returns a reference to it, otherwise None.

pub fn is_parenthesis(&self) -> bool

Returns true if the expression is wrapped in parenthesis.

pub fn as_parenthesis(&self) -> Option<&Parenthesis>

If the expression is an expression wrapped in parenthesis, returns a reference to it, otherwise None.

pub fn is_variable(&self) -> bool

Returns true if the expression is a variable.

pub fn as_variable(&self) -> Option<&Ident>

If the expression is a variable, returns a reference to it, otherwise None.

pub fn is_conditional(&self) -> bool

Returns true if the expression is a conditional.

pub fn as_conditional(&self) -> Option<&Conditional>

If the expression is a conditional, returns a reference to it, otherwise None.

pub fn is_func_call(&self) -> bool

Returns true if the expression is a function call.

pub fn as_func_call(&self) -> Option<&FuncCall>

If the expression is a function call, returns a reference to it, otherwise None.

pub fn is_traversal(&self) -> bool

Returns true if the expression is a traversal.

pub fn as_traversal(&self) -> Option<&Traversal>

If the expression is a traversal, returns a reference to it, otherwise None.

pub fn is_unary_op(&self) -> bool

Returns true if the expression is a unary op.

pub fn as_unary_op(&self) -> Option<&UnaryOp>

If the expression is a unary op, returns a reference to it, otherwise None.

pub fn is_binary_op(&self) -> bool

Returns true if the expression is a binary op.

pub fn as_binary_op(&self) -> Option<&BinaryOp>

If the expression is a binary op, returns a reference to it, otherwise None.

pub fn is_for_expr(&self) -> bool

Returns true if the expression is a for expression.

pub fn as_for_expr(&self) -> Option<&ForExpr>

If the expression is a for expression, returns a reference to it, otherwise None.