ObjectKey

Enum ObjectKey 

pub enum ObjectKey {
    Ident(Decorated<Ident>),
    Expression(Expression),
}
Represents an object key.

Variants



Ident(Decorated<Ident>)

Represents an unquoted identifier used as object key.



Expression(Expression)

Any valid HCL expression can be an object key.

Implementations

Source

impl ObjectKey

pub fn is_ident(&self) -> bool

Returns true if the object key is an identifier.

pub fn as_ident(&self) -> Option<&Ident>

If the object key is an identifier, returns a reference to it, otherwise None.

pub fn is_expr(&self) -> bool

Returns true if the object key is an expression.

pub fn as_expr(&self) -> Option<&Expression>

If the object key is an expression, returns a reference to it, otherwise None.