pub struct Traversal {
pub expr: Expression,
pub operators: Vec<Decorated<TraversalOperator>>,
/* private fields */
}Expand description
Traverse an expression to access attributes, object keys or element indices.
Fields
expr: ExpressionThe expression that the access operator is applied to.
operators: Vec<Decorated<TraversalOperator>>The traversal operators to apply to expr one of the other.
Implementations
sourceimpl Traversal
impl Traversal
sourcepub fn new(
expr: Expression,
operators: Vec<Decorated<TraversalOperator>>
) -> Traversal
pub fn new( expr: Expression, operators: Vec<Decorated<TraversalOperator>> ) -> Traversal
Creates a new Traversal structure from an expression and traversal operators that should
be applied to it.