pub struct UnaryOp {
pub operator: Spanned<UnaryOperator>,
pub expr: Expression,
/* private fields */
}Expand description
An operation that applies an operator to one expression.
Fields
operator: Spanned<UnaryOperator>The unary operator to use on the expression.
expr: ExpressionAn expression that supports evaluation with the unary operator.
Implementations