pub enum BlockBody {
    Multiline(Body),
    Oneline(Box<OnelineBody>),
}
Represents an HCL block body.

This can be either a multiline body with zero or more Structures, or a oneline body containing zero or one Attribute.

Variants



Multiline(Body)

A multiline block body with zero or more Structures.



Oneline(Box<OnelineBody>)

A oneline block body with zero or one Attributes.

Implementations

source

impl BlockBody

source

pub fn is_empty(&self) -> bool

Returns true if the block body contains no structures.

source

pub fn len(&self) -> usize

Returns the number of structures in the block body, also referred to as its ‘length’.

source

pub fn is_multiline(&self) -> bool

Returns true if this is a multiline block body.

source

pub fn is_oneline(&self) -> bool

Returns true if this is a oneline block body.

source

pub fn as_multiline(&self) -> Option<&Body>

If the BlockBody is of variant Multiline, returns a reference to the Body, otherwise None.

source

pub fn as_multiline_mut(&mut self) -> Option<&mut Body>

If the BlockBody is of variant Multiline, returns a mutable reference to the Body, otherwise None.

source

pub fn as_oneline(&self) -> Option<&OnelineBody>

If the BlockBody is of variant Oneline, returns a reference to the OnelineBody, otherwise None.

source

pub fn as_oneline_mut(&mut self) -> Option<&mut OnelineBody>

If the BlockBody is of variant Oneline, returns a mutable reference to the OnelineBody, otherwise None.

source

pub fn iter(&self) -> Iter<'_>

An iterator visiting all body structures in insertion order. The iterator element type is &'a Structure.

source

pub fn iter_mut(&mut self) -> IterMut<'_>

An iterator visiting all body structures in insertion order, with mutable references to the values. The iterator element type is &'a mut Structure.