Structure

Enum Structure 

pub enum Structure {
    Attribute(Attribute),
    Block(Block),
}
Represents an HCL structure.

There are two possible structures that can occur in an HCL Body: Attributes and Blocks.

Variants



Attribute(Attribute)

Represents an HCL attribute.



Block(Block)

Represents an HCL block.

Implementations

Source

impl Structure

pub fn is_attribute(&self) -> bool

Returns true if the structure represents an Attribute.

pub fn is_block(&self) -> bool

Returns true if the structure represents a Block.

pub fn into_attribute(self) -> Result<Attribute, Structure>

If the Structure is an Attribute, returns it.

Errors

An Err is returns with the same Structure that was passed in if it is not an Attribute.

pub fn as_attribute(&self) -> Option<&Attribute>

If the Structure is an Attribute, returns a reference to it, otherwise None.

pub fn as_attribute_mut(&mut self) -> Option<&mut Attribute>

If the Structure is an Attribute, returns a mutable reference to it, otherwise None.

pub fn into_block(self) -> Result<Block, Structure>

If the Structure is a Block, returns it.

Errors

An Err is returns with the same Structure that was passed in if it is not a Block.

pub fn as_block(&self) -> Option<&Block>

If the Structure is a Block, returns a reference to it, otherwise None.

pub fn as_block_mut(&mut self) -> Option<&mut Block>

If the Structure is a Block, returns a mutable reference to it, otherwise None.