Struct hcl_edit::structure::Block

source ·
pub struct Block {
    pub ident: Decorated<Ident>,
    pub labels: Vec<BlockLabel>,
    pub body: BlockBody,
    /* private fields */
}
Represents an HCL block which consists of a block identifier, zero or more block labels and a block body.

In HCL syntax this is represented as:

block_identifier "block_label1" "block_label2" {
  body
}

Fields

ident: Decorated<Ident>

The block identifier.

labels: Vec<BlockLabel>

Zero or more block labels.

body: BlockBody

Represents the Block’s body.

Implementations

source

impl Block

source

pub fn new(ident: Decorated<Ident>, body: BlockBody) -> Block

Creates a new Block from an identifier and a block body.