Struct hcl_edit::structure::Body

source ·
pub struct Body { /* private fields */ }
Represents an HCL config file body.

A Body consists of zero or more Attribute and Block HCL structures.

Implementations

source

impl Body

source

pub fn new() -> Self

Constructs a new, empty Body.

source

pub fn with_capacity(capacity: usize) -> Self

Constructs a new, empty Body with at least the specified capacity.

source

pub fn is_empty(&self) -> bool

Returns true if the body contains no structures.

source

pub fn len(&self) -> usize

Returns the number of structures in the body, also referred to as its ‘length’.

source

pub fn clear(&mut self)

Clears the body, removing all structures.

source

pub fn get(&self, index: usize) -> Option<&Structure>

Returns a reference to the structure at the given index, or None if the index is out of bounds.

source

pub fn get_mut(&mut self, index: usize) -> Option<&mut Structure>

Returns a mutable reference to the structure at the given index, or None if the index is out of bounds.

source

pub fn insert(&mut self, index: usize, structure: impl Into<Structure>)

Inserts a structure at position index within the body, shifting all structures after it to the right.

Panics

Panics if index > len.

source

pub fn push(&mut self, structure: impl Into<Structure>)

Appends a structure to the back of the body.

Panics

Panics if the new capacity exceeds isize::MAX bytes.

source

pub fn pop(&mut self) -> Option<Structure>

Removes the last structure from the body and returns it, or None if it is empty.

source

pub fn remove(&mut self, index: usize) -> Structure

Removes and returns the structure at position index within the body, shifting all elements after it to the left.

Like Vec::remove, the structure is removed by shifting all of the structures that follow it, preserving their relative order. This perturbs the index of all of those elements!

Panics

Panics if index is out of bounds.

source

pub fn iter(&self) -> Iter<'_>

An iterator visiting all body structures in insertion order. The iterator element type is &'a Structure.

source

pub fn iter_mut(&mut self) -> IterMut<'_>

An iterator visiting all body structures in insertion order, with mutable references to the values. The iterator element type is &'a mut Structure.