pub struct OnelineBody { /* private fields */ }
Represents a oneline HCL block body containing zero or one Attributes.

Implementations

source

impl OnelineBody

source

pub fn new() -> OnelineBody

Creates a new empty OnelineBody.

source

pub fn is_empty(&self) -> bool

Returns true if the block body is empty.

source

pub fn set_attribute(&mut self, attr: impl Into<Attribute>)

Sets the optional Attribute within the online block body.

source

pub fn as_attribute(&self) -> Option<&Attribute>

If the OnelineBody contains an Attribute, returns a reference to it, otherwise None.

source

pub fn as_attribute_mut(&mut self) -> Option<&mut Attribute>

If the OnelineBody contains an Attribute, returns a mutable reference to it, otherwise None.

source

pub fn trailing(&self) -> &RawString

Return a reference to raw trailing decor before the block’s closing }.

source

pub fn set_trailing(&mut self, trailing: impl Into<RawString>)

Set the raw trailing decor before the block’s closing }.