pub enum Element {
Literal(Spanned<String>),
Interpolation(Interpolation),
Directive(Directive),
}Expand description
An element of an HCL template.
Variants
Literal(Spanned<String>)
A literal sequence of characters to include in the resulting string.
Interpolation(Interpolation)
An interpolation sequence that evaluates an expression (written in the expression sub-language), and converts the result to a string value.
Directive(Directive)
An if or for directive that allows for conditional template evaluation.