IfTemplateExpr

Struct IfTemplateExpr 

pub struct IfTemplateExpr {
    pub cond_expr: Expression,
    pub template: Template,
    pub strip: Strip,
    /* private fields */
}
A type representing the %{ if cond_expr } sub-expression and the template that follows after it within an IfDirective.

Fields

cond_expr: Expression

The condition expression.

template: Template

The template that is included in the result string if the conditional expression evaluates to true.

strip: Strip

The whitespace strip behaviour to use on the template elements preceeding and following after the if expression.

Implementations

Source

impl IfTemplateExpr

pub fn new( cond_expr: impl Into<Expression>, template: Template, ) -> IfTemplateExpr

Creates a new IfTemplateExpr for a condition expression and a template.

pub fn preamble(&self) -> &RawString

Return a reference to the raw leading decor after the if’s opening {.

pub fn set_preamble(&mut self, preamble: impl Into<RawString>)

Set the raw leading decor after the if’s opening {.