Enum hcl_edit::expr::Expression
source · pub enum Expression {
Show 16 variants
Null(Decorated<Null>),
Bool(Decorated<bool>),
Number(Formatted<Number>),
String(Decorated<String>),
Array(Array),
Object(Object),
Template(StringTemplate),
HeredocTemplate(Box<HeredocTemplate>),
Parenthesis(Box<Parenthesis>),
Variable(Decorated<Ident>),
Conditional(Box<Conditional>),
FuncCall(Box<FuncCall>),
Traversal(Box<Traversal>),
UnaryOp(Box<UnaryOp>),
BinaryOp(Box<BinaryOp>),
ForExpr(Box<ForExpr>),
}Expand description
A type representing any expression from the expression sub-language.
Variants
Null(Decorated<Null>)
Represents a null value.
Bool(Decorated<bool>)
Represents a boolean.
Number(Formatted<Number>)
Represents a number, either integer or float.
String(Decorated<String>)
Represents a string that does not contain any template interpolations or template directives.
Array(Array)
Represents an HCL array.
Object(Object)
Represents an HCL object.
Template(StringTemplate)
Represents a string containing template interpolations and template directives.
HeredocTemplate(Box<HeredocTemplate>)
Represents an HCL heredoc template.
Parenthesis(Box<Parenthesis>)
Represents a sub-expression wrapped in parenthesis.
Variable(Decorated<Ident>)
Represents a variable identifier.
Conditional(Box<Conditional>)
Represents conditional operator which selects one of two rexpressions based on the outcome of a boolean expression.
FuncCall(Box<FuncCall>)
Represents a function call.
Traversal(Box<Traversal>)
Represents an attribute or element traversal.
UnaryOp(Box<UnaryOp>)
Represents an operation which applies a unary operator to an expression.
BinaryOp(Box<BinaryOp>)
Represents an operation which applies a binary operator to two expressions.
ForExpr(Box<ForExpr>)
Represents a construct for constructing a collection by projecting the items from another collection.