pub enum BlockBody {
Multiline(Body),
Oneline(Box<OnelineBody>),
}Expand description
Variants
Multiline(Body)
A multiline block body with zero or more Structures.
Oneline(Box<OnelineBody>)
A oneline block body with zero or one Attributes.
Implementations
sourceimpl BlockBody
impl BlockBody
sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of structures in the block body, also referred to as its ‘length’.
sourcepub fn is_multiline(&self) -> bool
pub fn is_multiline(&self) -> bool
Returns true if this is a multiline block body.
sourcepub fn is_oneline(&self) -> bool
pub fn is_oneline(&self) -> bool
Returns true if this is a oneline block body.
sourcepub fn as_multiline(&self) -> Option<&Body>
pub fn as_multiline(&self) -> Option<&Body>
If the BlockBody is of variant Multiline, returns a reference to the Body,
otherwise None.
sourcepub fn as_multiline_mut(&mut self) -> Option<&mut Body>
pub fn as_multiline_mut(&mut self) -> Option<&mut Body>
If the BlockBody is of variant Multiline, returns a mutable reference to the Body,
otherwise None.
sourcepub fn as_oneline(&self) -> Option<&OnelineBody>
pub fn as_oneline(&self) -> Option<&OnelineBody>
If the BlockBody is of variant Oneline, returns a reference to the OnelineBody,
otherwise None.
sourcepub fn as_oneline_mut(&mut self) -> Option<&mut OnelineBody>
pub fn as_oneline_mut(&mut self) -> Option<&mut OnelineBody>
If the BlockBody is of variant Oneline, returns a mutable reference to the
OnelineBody, otherwise None.