Struct hcl_edit::structure::OnelineBody
source · pub struct OnelineBody { /* private fields */ }Expand description
Represents a oneline HCL block body containing zero or one Attributes.
Implementations
sourceimpl OnelineBody
impl OnelineBody
sourcepub fn new() -> OnelineBody
pub fn new() -> OnelineBody
Creates a new empty OnelineBody.
sourcepub fn set_attribute(&mut self, attr: impl Into<Attribute>)
pub fn set_attribute(&mut self, attr: impl Into<Attribute>)
Sets the optional Attribute within the online block body.
sourcepub fn as_attribute(&self) -> Option<&Attribute>
pub fn as_attribute(&self) -> Option<&Attribute>
If the OnelineBody contains an Attribute, returns a reference to it, otherwise None.
sourcepub fn as_attribute_mut(&mut self) -> Option<&mut Attribute>
pub fn as_attribute_mut(&mut self) -> Option<&mut Attribute>
If the OnelineBody contains an Attribute, returns a mutable reference to it, otherwise
None.
sourcepub fn trailing(&self) -> &RawString
pub fn trailing(&self) -> &RawString
Return a reference to raw trailing decor before the block’s closing }.
sourcepub fn set_trailing(&mut self, trailing: impl Into<RawString>)
pub fn set_trailing(&mut self, trailing: impl Into<RawString>)
Set the raw trailing decor before the block’s closing }.